==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/slopemapdialog.cpp <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** SlopeMapWidget.cpp
*/
#include "slopemapdialog.h"
#include "slopemapdialog.moc"


#include "patternmodifierdialog.h"

SlopeMapWidget::SlopeMapWidget(QWidget *parent,slopeMap *s) :
	QWidget(parent,"SlopeMapWidget")
{

textureBase *tb;
QWidget *w;
int x;
	sm=s;

	label4=NULL;
	tw=NULL;
	tbw=NULL;
	turbulence=NULL;
	transformations=NULL;
	pmd=NULL;

	tab=new TabWidget(this,"Entry:",1);

	tb=sm->getFirstElement();
	while (tb!=NULL) {

		switch(tb->getType()) {
			case SLOPEENTRY:
				w=(QWidget *)new SlopeEntryWidget(NULL,(slopeEntry *)tb);
	     			slopewidget.append( (SlopeEntryWidget *)w );
				widgetlist.append (w);
				x=widgetlist.length()-1;
				tab->addWidget(w,x,tb->getName() );

			break;
			case TRANSFORMATIONS:
				transformations=new QPushButton("Transformations...",this);
				connect (transformations,SIGNAL(clicked()),this,SLOT(transformationsPressed()) );
				tw=new TransformationsWidget(NULL,(Transformations*)tb );
				tw->setCaption("Transformations");
			break;
			case TURBULENCEMODIFIER:
				turbulence=new QPushButton("Turbulence...",this);
				connect (turbulence,SIGNAL(clicked()),this,SLOT(turbulencePressed()) );
				tbw=new TurbulenceWidget(NULL,(Turbulence*)tb );
				tbw->setCaption("Turbulence");

			break;
			default:
			break;
		}

		tb=sm->getNextElement();
	}

	line=new QLineEdit(this);
	line->setText(sm->getName());
	n=new QLabel("Name:",this);


	active=new QCheckBox("Active",this);
	active->setChecked(sm->active() );

	add=new QPushButton("Add Element",this);
	connect(add,SIGNAL(clicked()),this,SLOT(addClicked()) );

	if (slopewidget.length()==0) label4=new QLabel("no entrys in map ! ",this);	
	
	pmd=new PatternModifierWidget(this,sm->getMapModifier() );

	resize(200,300);
	
}

SlopeMapWidget::~SlopeMapWidget()
{
}

void SlopeMapWidget::addClicked()
{
slopeEntry *c=new slopeEntry(sm);
QWidget *w;
int x;
	if (label4) {
		delete tab;
		tab=new TabWidget(this,"Entry:",1);
		tab->setGeometry(10,185,320,190);
		tab->show();
		delete label4;
		label4=NULL;
	}
	sm->add(c);
	w=(QWidget *)new SlopeEntryWidget(NULL,(slopeEntry *)c);
	slopewidget.append( (SlopeEntryWidget *)w );
	widgetlist.append (w);
	x=widgetlist.length()-1;
	tab->addWidget(w,x,c->getName() );
	tab->select(x);
}

void SlopeMapWidget::getSlopeMap()
{
int i;
	if (tw) tw->getTransformations();
	if (tbw) tbw->getTurbulence();
	sm->setName( line->text());
	pmd->getPatternModifier();
	for (i=0;i<slopewidget.length();i++) if (slopewidget[i]) slopewidget[i]->getSlopeEntry();	
	sm->setActive(active->isChecked(),NULL);
}

void SlopeMapWidget::transformationsPressed()
{
	tw->resize(200,440);
	tw->setMinimumSize(200,440);
	tw->exec();
}

void SlopeMapWidget::turbulencePressed()
{
	tbw->resize(270,170);
	tbw->setMinimumSize(270,170);
	tbw->exec();
}

void SlopeMapWidget::paintEvent(QPaintEvent* qp)
{

	add->setGeometry(10,40,110,25);

	n->setGeometry(10,10,50,25);
	line->setGeometry(65,10,150,25);

	active->setGeometry(220,10,60,25);
	
	if(pmd) pmd->setGeometry(10,80,320,100);

	if (transformations) transformations->setGeometry(20,160,110,25);
	if (turbulence) turbulence->setGeometry(150,160,110,25);

        if (label4) {
		label4->setGeometry(width()/2-140,240,280,25);
		 tab->setGeometry(-400,-300,320,210);
	}
	else tab->setGeometry(10,185,300,190);

	QWidget::paintEvent(qp);
}

//------------------------------------------------------------------------

SlopeMapDialog::SlopeMapDialog(QWidget *parent,slopeMap *sm) :
	QDialog(parent,"SlopeMapDialog",true)
{

	setCaption("SlopeMap");

	ok=new QPushButton("Okay",this);
	cancel=new QPushButton("Cancel",this);

	pw=new SlopeMapWidget(this,sm);

	connect (ok,SIGNAL(pressed()),this,SLOT(okayPressed()) );
	connect (cancel,SIGNAL(pressed()),this,SLOT(cancelPressed()) );

	resize(340,410);
	setMinimumSize(340,410);
	setMaximumSize(340,410);
	
}

SlopeMapDialog::~SlopeMapDialog()
{
}


void SlopeMapDialog::cancelPressed()
{
	QDialog::done(0);
}

void SlopeMapDialog::okayPressed()
{
	pw->getSlopeMap();
	QDialog::done(1);
}

void SlopeMapDialog::paintEvent(QPaintEvent* qp)
{
	int w=width();
	int h=height();


	
	cancel->setGeometry(w-65,h-30,60,25);
	ok->setGeometry(w-65-45,h-30,40,25);

	pw->setGeometry(0,0,w,h-35);

	QDialog::paintEvent(qp);
}

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/slopemapdialog.cpp <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** slopemapdialog.cpp
*/
#include "slopemapdialog.h"
#include "slopemapdialog.moc"


#include "patternmodifierdialog.h"

#include <kapp.h>

SlopeMapWidget::SlopeMapWidget(QWidget *parent,slopeMap *s) :
	TextureWidgetBase(parent,"SlopeMapWidget")
{
	sm=s;

	pmd=new PatternModifierWidget(this,s->getMapModifier(),1 );
	connect(pmd,SIGNAL(valueChanged()),this,SIGNAL(valueChanged()) );

	tbasew=new TextureBaseWidget(this,sm);
	connect(tbasew,SIGNAL(valueChanged()),this,SIGNAL(valueChanged()) );

	paintEvent(NULL);
}

SlopeMapWidget::~SlopeMapWidget()
{
	if (tbasew) delete tbasew;
	if (pmd) delete pmd;
}

void SlopeMapWidget::getValue()
{
	if (pmd) pmd->getPatternModifier();
	if (tbasew) tbasew->getTextureBase();
}

QSize SlopeMapWidget::sizeHint() const
{
	return qs;
}

void SlopeMapWidget::paintEvent(QPaintEvent* qp)
{
int w=tbasew->sizeHint().width();
int h=tbasew->sizeHint().height();
int y=0,w1=0,h1=0;

	tbasew->setGeometry(10,10,w,h);
	y+=h+15;


	w1=pmd->sizeHint().width();
	h1=pmd->sizeHint().height();
        pmd->setGeometry(10,y,w1,h1);

	w=MAX(w1,w);
	h=y+h1+10;

	qs.setWidth(w+10);
	qs.setHeight(h+10);
	if (qp) QWidget::paintEvent(qp);
}

//------------------------------------------------------------------------

SlopeMapDialog::SlopeMapDialog(QWidget *parent,slopeMap *sm) :
	QDialog(parent,"SlopeMapDialog",true)
{
	setCaption(i18n("SlopeMap"));

	ok=new QPushButton(i18n("Ok") ,this);
	cancel=new QPushButton(i18n("Cancel"),this);

	pw=new SlopeMapWidget(this,sm);

	connect (ok,SIGNAL(pressed()),this,SLOT(okayPressed()) );
	connect (cancel,SIGNAL(pressed()),this,SLOT(cancelPressed()) );

	paintEvent(NULL);
}

SlopeMapDialog::~SlopeMapDialog()
{
	if (pw) delete pw;
	if (ok) delete ok;
	if (cancel) delete cancel;
}


void SlopeMapDialog::cancelPressed()
{
	QDialog::done(0);
}

void SlopeMapDialog::okayPressed()
{
	pw->getValue();
	QDialog::done(1);
}

void SlopeMapDialog::paintEvent(QPaintEvent* qp)
{
 	int w=pw->sizeHint().width();
	int h=pw->sizeHint().height();

	int w1=ok->sizeHint().width();
	int w2=cancel->sizeHint().width();
	int h1=ok->sizeHint().height();

	cancel->setGeometry(w-w2-5,h+5,w2,h1);
	ok->setGeometry(w-w2-w1-10,h+5,w1,h1);

	pw->setGeometry(0,0,w,h);

	setMinimumSize(w,h);
	setMaximumSize(w,h);

	if (qp) QDialog::paintEvent(qp);
}
